@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -74,7 +74,12 @@ public class ParallelsSpamdService implements SpamdService {
         ConfigView view = factory.getView(session.getUserId(), session.getContextId());
 
         ComposedConfigProperty<V> property = view.property(propertyName, clazz);
-        return (null != property && property.isDefined()) ? property.get() : defaultValue;
+        if (null == property) {
+            return defaultValue;
+        }
+
+        V value = property.get();
+        return value == null ? defaultValue : value;
     }
 
     private int getPort(Session session) throws OXException {
